@@ -36,7 +36,7 @@ class Sequence(KerasSequence):
                 "Given elapsed epochs must be a non-negative integer."
             )
         self._sample_number = sample_number
-        Sequence.batch_size.fset(self, batch_size) # pylint: disable=no-member
+        Sequence.batch_size.fset(self, batch_size)  # pylint: disable=no-member
         self._elapsed_epochs = elapsed_epochs
 
     def on_epoch_end(self):
@@ -55,14 +55,6 @@ class Sequence(KerasSequence):
             raise ValueError(
                 "Given batch size must be a strictly positive integer."
             )
-        if self._sample_number < batch_size:
-            raise ValueError((
-                "Given sequence length ({}) "
-                "is smaller than a single batch of size ({})."
-            ).format(
-                self._sample_number,
-                batch_size
-            ))
         self._batch_size = batch_size
 
     def reset(self):
